# PressurePyLite
no dash version of PressurePy

made to run on a raspberry pi to control 2 arduinos (one controlling a pump/one to read a sensor)


###arguments
-s -> "change the port of the sensor arduino"

-p -> "change the port of the pump arduino"

-t -> "change the pressure"
